first_experiment = """
Single Decision: The experiment consists of a single round in which you are matched with another randomly selected person. Note: You will only make a single set of decisions in this experiment.

Decisions: One of you will be designated as a Proposer (initial decision-maker) who will begin the round by proposing a division of an amount of money, $10.00. The other person, designated as responder, is told of the proposed division and must either accept it or not.

Role: You have been randomly assigned to be a Proposer (or initial decision-maker) in this process, and you will begin by suggesting amounts of money for each of you that sum to $10.00.

Earnings: If the responder accepts the proposed division, then each person earns their part of the proposed division. If the responder rejects, both earn $0.00.

Please remember that you are randomly matched with another participant, and that this process will not be repeated, you make only one decision.

The proposer (initial decision-maker) in each pair suggests a division of the $10.00; this proposal determines earnings for the round if it is accepted. A rejection produces earnings of $0.00 for each person. If the proposal is rejected, earnings are $0.00 for both proposer and responder.

After you and the person you are matched with have made your decisions, earnings will be determined and announced. There will not be another round of bargaining with this person or with anyone else.
"""

second_experiment = """
Single Decision: The experiment consists of a single round in which you are matched with another randomly selected person. Note: You will only make a single set of decisions in this experiment.

Initial Decisions: One of you will be designated as a Proposer (initial decision-maker) who will begin the round by proposing a division of an amount of money, $10.00. The other person, designated as responder, is told of the proposed division and must either accept it or not.

Second Stage Decisions: If the responder (second-mover) rejects, then the pie size is reduced to $3.00, and the responder can make a proposal for how to divide this lower amount. If a counter proposal is made, the initial proposer (first mover), must either accept it or not (no additional proposals would be allowed in this round).

Role: You have been randomly assigned to be a Proposer (or initial decision-maker) in this process, and you will begin by suggesting amounts of money for each of you that sum to $10.00.

Earnings: If the responder accepts the proposed division, then each person earns their part of the proposed division. If the responder rejects, then the amount of money to be divided becomes $3.00, and the responder must make a counter-proposal on how to divide this new amount. If the initial proposer accepts this counter-proposal, then it is implemented. If the counter-proposal is rejected, then each person earns $0.00.

Fixed Payments: In addition to the amounts earned (if any) from the bargaining process, each person may receive a fixed payment that is independent of the outcome of the bargaining outcome. Your fixed payment will be: $4.00 and the fixed payment of the other person will be $0.00. Note: These fixed payments are received each round, irrespective of the bargaining outcomes.

Please remember that you are randomly matched with another participant, and that this process will not be repeated, you make only one decision.

The proposer (initial decision-maker) in each pair suggests a division of the $10.00; this proposal determines earnings for the round if it is accepted.

If the initial proposal is rejected, the amount of money to be divided is changed to $3.00, and the responder must now make a counter-proposal for how to divide this new amount.

Then the initial proposer (first mover) must either accept the counter-proposal or reject. An acceptance implements the counter-proposal, and a rejection results in earnings of $0.00 (for both) from the bargaining process.

After you and the person you are matched with have made your decisions, earnings will be determined and announced. There will not be another round of bargaining with this person or with anyone else.

In addition to these earnings (if any), the initial proposer receives $4.00 and the responder receives $0.00 each round, indpendently of the other outcomes.

Bargaining Process: This process has changed.
Responder Decision (Accept or Make Counter-Proposal): If the responder accepts the initial proposal, it is implemented, but if the responder rejects, then the responder must make a counter-proposal to divide an amount of money, $3.00. Then the proposer must either accept or reject this counter-proposal. Final acceptance by the proposer implements the counter-proposal, and rejection results in zero earnings for both from the bargaining process.
Pie Size: The amount of money to be divided is unchanged at $10.00.
Fixed Payments: In addition to these earnings (if any), the proposer receives $4.00 and the responder receives $0.00 each round.
Matching Method: The proposer/responder pairs will remain the same for all rounds in this part.

In the first stage, you enter a proposed money amount for yourself, between $0.00 and $10.00. The remainder (between $0.00 and $10.00) is what is proposed for the responder. If your proposal is rejected, the amount of money available will be reduced to $3.00, and the other person will suggest amounts for each of you that sum to $3.00.
"""